pub struct BufferingSrtFrameWriter { /* private fields */ }Expand description
A buffering SrtWriter which is meant to be called for every frame.
This buffers values from each frame until the next frame. In this way, it can calculate start and stop times for each frame. The first call to Self::add_frame thus only stores the buffer, and the buffered value is written upon Self::close or Self::drop.
Implementations
Sourceimpl BufferingSrtFrameWriter
impl BufferingSrtFrameWriter
pub fn new(wtr: Box<dyn Write>) -> Self
pub fn add_frame(&mut self, pts: Duration, val: String) -> Result<()>
Sourcepub fn flush(&mut self) -> Result<()>
pub fn flush(&mut self) -> Result<()>
Flush the underlying writer.
Note that this does not flush the currently buffered value, as that would require creating a new timestamp.
pub fn close(self) -> Result<()>